<!--
 * @Description: 
 * @Author: @liulin
 * @Date: 2023-03-07 16:14:31
 * @LastEditors: Do not edit
 * @LastEditTime: 2023-03-08 11:22:20
-->
<template>
  <el-dialog
    :title="title"
    :visible.sync="visible"
    width="50%"
    top="4vh"
    :before-close="handleDialogClose"
    :close-on-click-modal="false"
  >
    <el-table
      stripe
      size="mini"
      v-loading="loading"
      ref="table"
      :data="tableData"
      :height="600"
      :style="{width: '100%'}"
      class="single-select-table"
      @selection-change="handleSelectionChange"
    >
      <el-table-column
        type="selection"
        width="55"
        align="center"
      ></el-table-column>
      <el-table-column type="index" width="100" label="序号" align="center">
      </el-table-column>
      <el-table-column
        prop="demandTopic"
        show-overflow-tooltip
        min-width="120"
        align="center"
        label="需求题目"
      >
      </el-table-column>
      <el-table-column
        prop="demandSourceChannel"
        show-overflow-tooltip
        min-width="120"
        align="center"
        label="来源渠道"
      >
        <template v-slot="{row}">
          {{ getDictName('ggbb_lyqd', row.demandSourceChannel) }}
        </template>
      </el-table-column>
      <el-table-column
        prop="demandField"
        show-overflow-tooltip
        min-width="120"
        align="center"
        label="所属领域"
      >
        <template v-slot="{row}">
          {{ getDictName('ggbb_ssly', row.demandField) }}
        </template>
      </el-table-column>
      <el-table-column
        prop="demandRunway"
        show-overflow-tooltip
        min-width="120"
        align="center"
        label="所属跑道"
      >
        <template v-slot="{row}">
          {{ getDictName('ggbb_sspd', row.demandRunway) }}
        </template>
      </el-table-column>
      <el-table-column
        prop="demandDescription"
        show-overflow-tooltip
        min-width="180"
        align="center"
        label="需求描述"
      >
      </el-table-column>
    </el-table>
    <pagination
      ref="paginationPanel"
      style="margin-top: 10px"
      :pageResult="params.pageBean"
      @size-change="handleSizeChange"
      @current-change="handleCurrentChange"
    />
    <span slot="footer" class="dialog-footer">
      <el-button type="primary" @click="submit">
        确认
      </el-button>
      <el-button @click="visible = false">
        取消
      </el-button>
    </span>
  </el-dialog>
</template>

<script>
import pagination from '@/components/pagination'
import utils from '@/utils.js'
import req from '@/request.js'
const portal = window.context.portal
export default {
  components: {
    pagination
  },
  data() {
    return {
      title: '选择',
      visible: false,
      loading: false,
      tableData: [],
      multipleSelection: [],
      params: {
        pageBean: {
          page: 1,
          pageSize: 20,
          total: 0
        }
      },
      pageResult: {
        page: 1,
        pageSize: 20,
        total: 0
      }
    }
  },
  created() {},
  methods: {
    open() {
      this.visible = true
      this.loadData(this.params)
    },
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    loadData(params) {
      this.loading = true
      req
        .post(
          portal + '/bizBlockageCardTransfer/v1/getLibraryList',
          params
        )
        .then(res => {
          this.loading = false
          const data = (res && res.data && res.data.value) || {}
          this.tableData = data.rows || []
          this.params.pageBean = {
            page: data.page,
            pageSize: data.pageSize,
            total: data.total
          }
        })
    },
    handleDialogClose() {
      this.visible = false
    },
		submit() {
			this.visible = false
			this.$emit('select', this.multipleSelection)
		},
    handleSelectionChange(val) {
      // 单选
      if (val.length > 1) {
        this.$refs.table.clearSelection()
        this.$refs.table.toggleRowSelection(val.pop())
      }
      this.multipleSelection = val
    },
    handleCurrentChange(page) {
      this.params.pageBean = {...this.params.pageBean, page}
      this.loadData(this.params)
    },
    handleSizeChange(pageSize) {
      this.params.pageBean = {...this.params.pageBean, pageSize}
      this.loadData(this.params)
    }
  }
}
</script>

<style lang="scss" scoped>
/deep/ .single-select-table thead .el-table-column--selection .cell {
  display: none;
}
</style>
